@@ -107,16 +107,18 @@ UNDER_DEVELOPMENT_RANGES_TXT = """
 0F00..0FFF; Tibetan
 """
 
-DEEMED_UI_SCRIPTS_SET = frozenset({
-  'Armn', # Armenian
-  'Cher', # Cherokee
-  'Ethi', # Ethiopic
-  'Geor', # Georgian
-  'Hebr', # Hebrew
-  'Sinh', # Sinhala
-  'Zmth', # Math
-  'Zsye', # Emoji
-})
+DEEMED_UI_SCRIPTS_SET = frozenset(
+    {
+        "Armn",  # Armenian
+        "Cher",  # Cherokee
+        "Ethi",  # Ethiopic
+        "Geor",  # Georgian
+        "Hebr",  # Hebrew
+        "Sinh",  # Sinhala
+        "Zmth",  # Math
+        "Zsye",  # Emoji
+    }
+)
 
 # A mapping from scripts to ttfautohint script ids.
 # Most of the keys correspond to scripts we hinted for phase 2.
@@ -129,34 +131,34 @@ DEEMED_UI_SCRIPTS_SET = frozenset({
 # ttfautohint supports two version of Georgian identified by 'geor'
 # and 'geok', we assume 'geor'.
 HINTED_SCRIPTS = {
-    'Arab': 'arab',  # Arabic
-    'Armn': 'armn',  # Armenian
-    'Beng': 'beng',  # Bengali
-    'Cham': None,    # Cham
-    'Cher': 'cher',  # Cherokee (not hinted in phase2)
-    'Cyrl': 'cyrl',  # Cyrillic (part of LGC)
-    'Deva': 'deva',  # Devanagari
-    'Ethi': 'ethi',  # Ethiopic
-    'Geor': 'geor',  # Georgian (Mkhedruli, not Khutsuri)
-    'Grek': 'grek',  # Greek (part of LGC)
-    'Gujr': 'gujr',  # Gujarati
-    'Guru': 'guru',  # Gurmukhi
-    'Hebr': 'hebr',  # Hebrew
-    'Khmr': 'khmr',  # Khmer
-    'Knda': 'knda',  # Kannada
-    'LGC': 'no-script',     # LGC, autohint but not to any particular script
-    'Laoo': 'lao',   # Lao (only one 'o' for ttfautohint)
-    'Latn': 'latn',  # Latin (part of LGC)
-    'MONO': 'no-script',    # MONO, autohint like lgc
-    'Mlym': 'mlym',  # Malayalam
-    'Mymr': 'mymr',  # Myanmar
-    'Orya': None,    # Oriya
-    'Sinh': 'sinh',  # Sinhala
-    'Taml': 'taml',  # Tamil
-    'Telu': 'telu',  # Telugu
-    'Thaa': None,    # Thaana
-    'Thai': 'thai',  # Thai
-    'Tibt': None,    # Tibetan
+    "Arab": "arab",  # Arabic
+    "Armn": "armn",  # Armenian
+    "Beng": "beng",  # Bengali
+    "Cham": None,  # Cham
+    "Cher": "cher",  # Cherokee (not hinted in phase2)
+    "Cyrl": "cyrl",  # Cyrillic (part of LGC)
+    "Deva": "deva",  # Devanagari
+    "Ethi": "ethi",  # Ethiopic
+    "Geor": "geor",  # Georgian (Mkhedruli, not Khutsuri)
+    "Grek": "grek",  # Greek (part of LGC)
+    "Gujr": "gujr",  # Gujarati
+    "Guru": "guru",  # Gurmukhi
+    "Hebr": "hebr",  # Hebrew
+    "Khmr": "khmr",  # Khmer
+    "Knda": "knda",  # Kannada
+    "LGC": "no-script",  # LGC, autohint but not to any particular script
+    "Laoo": "lao",  # Lao (only one 'o' for ttfautohint)
+    "Latn": "latn",  # Latin (part of LGC)
+    "MONO": "no-script",  # MONO, autohint like lgc
+    "Mlym": "mlym",  # Malayalam
+    "Mymr": "mymr",  # Myanmar
+    "Orya": None,  # Oriya
+    "Sinh": "sinh",  # Sinhala
+    "Taml": "taml",  # Tamil
+    "Telu": "telu",  # Telugu
+    "Thaa": None,  # Thaana
+    "Thai": "thai",  # Thai
+    "Tibt": None,  # Tibetan
 }
 
 
@@ -176,79 +178,123 @@ URDU_RANGES = """
 # extra characters needed.
 URDU_EXTRA = "2010..2011"
 
+
 def _char_set(compact_set_text):
     result = set()
     prev = -1
-    for part in compact_set_text.split(','):
-        sep_index = part.find('..')
+    for part in compact_set_text.split(","):
+        sep_index = part.find("..")
         if sep_index == -1:
             cp = int(part, base=16)
             assert cp > prev
-            # print '%04x' % cp
+            # print('%04x' % cp)
             result.add(cp)
             prev = cp
         else:
-          start = int(part[:sep_index], base=16)
-          end = int(part[sep_index + 2:], base=16)
-          # print '%04x..%04x' % (start, end)
-          assert start > prev
-          assert end > start
-          for cp in range(start, end + 1):
-              result.add(cp)
-          prev = end
+            start = int(part[:sep_index], base=16)
+            end = int(part[sep_index + 2 :], base=16)
+            # print('%04x..%04x' % (start, end))
+            assert start > prev
+            assert end > start
+            for cp in range(start, end + 1):
+                result.add(cp)
+            prev = end
     return result
 
+
 def urdu_set():
     return _char_set(URDU_RANGES) | _char_set(URDU_EXTRA)
 
+
 def ascii_letters():
-    return _char_set('0041..005a,0061..007a')
+    return _char_set("0041..005a,0061..007a")
+
 
 def char_range(start, end):
-    return list(range(start, end+1))
+    return list(range(start, end + 1))
+
 
 COPTIC_EPACT = char_range(0x102E0, 0x102FB)
 ARABIC_MATH = char_range(0x1EE00, 0x1EEF1)
 
 P3_EXTRA_CHARACTERS_NEEDED = {
     # nothing additional outside block
-    'Ahom': [ ],
-
+    "Ahom": [],
     # According to Roozbeh (and existing fonts) the following punctuation and
     # digits are used with and interact with Arabic characters.
-    'Arab': char_range(0x0030, 0x0039) + [
+    "Arab": char_range(0x0030, 0x0039)
+    + [
         # exclamation mark, comma, full stop, colon, NBS, guillimets
-        0x0021, 0x002c, 0x002e, 0x003a, 0x00a0, 0x00ab, 0x00bb,
-        0x06dd,           # Arabic end of Ayah
-        0x2010, 0x2011,   # Hyphen and non-breaking hyphen need different shapes
-        0x204F, 0x2E41,   # For Sindhi
-        0xfd3e, 0xfd3f],  # ornate left and right paren (in Noto Naskh)
-
+        0x0021,
+        0x002C,
+        0x002E,
+        0x003A,
+        0x00A0,
+        0x00AB,
+        0x00BB,
+        0x06DD,  # Arabic end of Ayah
+        0x2010,
+        0x2011,  # Hyphen and non-breaking hyphen need different shapes
+        0x204F,
+        0x2E41,  # For Sindhi
+        0xFD3E,
+        0xFD3F,
+    ],  # ornate left and right paren (in Noto Naskh)
     # like Arabic, but Sindi is not written in Nastaliq so omitted.
-    'Aran': char_range(0x0030, 0x0039) + [
+    "Aran": char_range(0x0030, 0x0039)
+    + [
         # exclamation mark, comma, full stop, colon, NBS, guillimets
-        0x0021, 0x002c, 0x002e, 0x003a, 0x00a0, 0x00ab, 0x00bb,
-        0x06dd,           # Arabic end of Ayah
-        0x2010, 0x2011,   # Hyphen and non-breaking hyphen need different shapes
-        0xfd3e, 0xfe3f],  # ornate left and right paren (in Noto Naskh)
-
+        0x0021,
+        0x002C,
+        0x002E,
+        0x003A,
+        0x00A0,
+        0x00AB,
+        0x00BB,
+        0x06DD,  # Arabic end of Ayah
+        0x2010,
+        0x2011,  # Hyphen and non-breaking hyphen need different shapes
+        0xFD3E,
+        0xFE3F,
+    ],  # ornate left and right paren (in Noto Naskh)
     # Characters referenced in Armenian encoding cross ref page as shown in
     # see http://www.unicode.org/L2/L2010/10354-n3924-armeternity.pdf
     # also see http://man7.org/linux/man-pages/man7/armscii-8.7.html
     # left and right paren, comma, hyphen-minus, period, section,
     # no break space, left and right guillimet, hyphen, em dash, ellipsis
     # presentation forms FB13-FB17
-    'Armn': [0x0028, 0x0029, 0x002C, 0x002D, 0x002E, 0x00A0,
-             0x00A7, 0x00AB, 0x00BB, 0x2010, 0x2014, 0x2026],
-
-    'Avst': [0x2E30, 0x2E31,  # From Core Specification and NamesList.txt
-             0x200C],  # www.unicode.org/L2/L2007/07006r-n3197r-avestan.pdf
-
+    "Armn": [
+        0x0028,
+        0x0029,
+        0x002C,
+        0x002D,
+        0x002E,
+        0x00A0,
+        0x00A7,
+        0x00AB,
+        0x00BB,
+        0x2010,
+        0x2014,
+        0x2026,
+    ],
+    "Avst": [
+        0x2E30,
+        0x2E31,  # From Core Specification and NamesList.txt
+        0x200C,
+    ],  # www.unicode.org/L2/L2007/07006r-n3197r-avestan.pdf
     # From http://www.unicode.org/L2/L2014/14064r-n4537r-cherokee.pdf section 8
-    'Cher': [
-        0x0300, 0x0301, 0x0302, 0x0304, 0x030B,
-        0x030C, 0x0323, 0x0324, 0x0330, 0x0331],
-
+    "Cher": [
+        0x0300,
+        0x0301,
+        0x0302,
+        0x0304,
+        0x030B,
+        0x030C,
+        0x0323,
+        0x0324,
+        0x0330,
+        0x0331,
+    ],
     # From Core Specification:
     # period, colon, semicolon, middle dot
     # combining: grave, macron, overline, dot above, double overline
@@ -256,26 +302,58 @@ P3_EXTRA_CHARACTERS_NEEDED = {
     # from http://std.dkuug.dk/JTC1/SC2/WG2/docs/n2636.pdf
     # oblique double hyphen, diaeresis, apostrophe, comb. circumflex, acute,
     # hyphen-minus, hyphen
-    'Copt': [
-        0x002E, 0x003A, 0x003B, 0x00B7,
-        0x0300, 0x0304, 0x0305, 0x0307, 0x033F,
-        0x0374, 0x0375, 0xFE24, 0xFE25, 0xFE26,
-        0x2E17, 0x0308, 0x2019, 0x0302, 0x0301,
-        0x002D, 0x2010,
-        ],
-
+    "Copt": [
+        0x002E,
+        0x003A,
+        0x003B,
+        0x00B7,
+        0x0300,
+        0x0304,
+        0x0305,
+        0x0307,
+        0x033F,
+        0x0374,
+        0x0375,
+        0xFE24,
+        0xFE25,
+        0xFE26,
+        0x2E17,
+        0x0308,
+        0x2019,
+        0x0302,
+        0x0301,
+        0x002D,
+        0x2010,
+    ],
     # Elbasan
     # see http://www.unicode.org/L2/L2011/11050-n3985-elbasan.pdf
     # adds combining overbar and greek numerals for ones and tens, and
     # both stigma/digamma for 6.
     # greek capital alpha beta gamma delta epsilon stigma/digamma zeta eta theta
     # iota kappa lambda mu nu xi omicron pi koppa
-    'Elba': [0x00B7, 0x0305,
-             0x0391, 0x0392, 0x0393, 0x0394, 0x0395,
-             0x03DA, 0x03DD, 0x0396, 0x0397, 0x0398,
-             0x0399, 0x039A, 0x039B, 0x039C, 0x039D,
-             0x039E, 0x039F, 0x03A0, 0x03DE],
-
+    "Elba": [
+        0x00B7,
+        0x0305,
+        0x0391,
+        0x0392,
+        0x0393,
+        0x0394,
+        0x0395,
+        0x03DA,
+        0x03DD,
+        0x0396,
+        0x0397,
+        0x0398,
+        0x0399,
+        0x039A,
+        0x039B,
+        0x039C,
+        0x039D,
+        0x039E,
+        0x039F,
+        0x03A0,
+        0x03DE,
+    ],
     # Ethiopic
     # See http://abyssiniagateway.net/fidel/l10n/
     # Recommends combining diaeresis 'for scholarly use', should look Ethiopian.
@@ -293,14 +371,29 @@ P3_EXTRA_CHARACTERS_NEEDED = {
     #   (plus sign to here all from keyboard doc)
     # exclamation point, left paren, right paren, ellipsis (web sites use them)
     # hyphen (used in hyphenated names in Amharaic, see wikipedia page)
-    'Ethi': char_range(0x0030, 0x0039) + [
+    "Ethi": char_range(0x0030, 0x0039)
+    + [
         0x0308,
-        0x002B, 0x002C, 0x002D, 0x002E, 0x002F,
-        0x003D, 0x003F, 0x2018, 0x2019, 0x201C, 0x201D,
-        0x00AB, 0x00BB, 0x22EE,
-        0x0021, 0x0028, 0x0029, 0x2026,
-        0x2010],
-
+        0x002B,
+        0x002C,
+        0x002D,
+        0x002E,
+        0x002F,
+        0x003D,
+        0x003F,
+        0x2018,
+        0x2019,
+        0x201C,
+        0x201D,
+        0x00AB,
+        0x00BB,
+        0x22EE,
+        0x0021,
+        0x0028,
+        0x0029,
+        0x2026,
+        0x2010,
+    ],
     # Georgian
     # see example news article: http://www.civil.ge/geo/article.php?id=29970
     # ascii digits,
@@ -310,24 +403,37 @@ P3_EXTRA_CHARACTERS_NEEDED = {
     # see core standard:
     # middle dot, word separator middle dot, archaic punctuation (includes two
     # dot punctuation at 205A)
-    'Geor': char_range(0x0030, 0x0039) + [
-        0x0021, 0x0025, 0x0028, 0x0029, 0x002C, 0x002D,
-        0x002E, 0x003A, 0x003B, 0x00A0,
-        0x2014, 0x201C, 0x201E, 0x2026,
-        0x00B7, 0x2E31] + char_range(0x2056, 0x205E) + char_range(0x2E2A, 0x2E2D),
-
+    "Geor": char_range(0x0030, 0x0039)
+    + [
+        0x0021,
+        0x0025,
+        0x0028,
+        0x0029,
+        0x002C,
+        0x002D,
+        0x002E,
+        0x003A,
+        0x003B,
+        0x00A0,
+        0x2014,
+        0x201C,
+        0x201E,
+        0x2026,
+        0x00B7,
+        0x2E31,
+    ]
+    + char_range(0x2056, 0x205E)
+    + char_range(0x2E2A, 0x2E2D),
     # Hatran
     # see http://www.unicode.org/L2/L2012/12312-n4324-hatran.pdf (most info, but
     # not latest assignment, which doesn't have all digits shown here)
     # single and double vertical line, also ZWNJ in case ligatures need breaking
     # might want to ligate hatran digit 1 forms 11 (2), 111 (3), 1111 (4) to
     # look as the suggested (dropped) digits were represented in the doc.
-    'Hatr': [ 0x007C, 0x2016, 0x200C ],
-
+    "Hatr": [0x007C, 0x2016, 0x200C],
     # Anatolian Hieroglyphs
     # see http://www.unicode.org/L2/L2012/12213-n4282-anatolian.pdf
-    'Hluw': [0x200B],
-
+    "Hluw": [0x200B],
     # Old Hungarian
     # see  http://www.unicode.org/L2/L2012/12168r-n4268r-oldhungarian.pdf
     # letters with LTR override mirror reverse (!) "which has to be handled by
@@ -338,147 +444,187 @@ P3_EXTRA_CHARACTERS_NEEDED = {
     # double high-reversed-9 quote, reversed semicolon, reversed question mark,
     #   reversed comma, double low-reversed-9 quote,
     # hyphen (the official one)
-    'Hung': [ 0x200D, 0x2E31, 0x205A, 0x205D, 0x205E,
-              0x0021, 0x002C, 0x002D, 0x002E, 0x003A,
-              0x201F, 0x204F, 0x2E2E, 0x2E41, 0x2E42,
-              0x2010,
-            ],
-
+    "Hung": [
+        0x200D,
+        0x2E31,
+        0x205A,
+        0x205D,
+        0x205E,
+        0x0021,
+        0x002C,
+        0x002D,
+        0x002E,
+        0x003A,
+        0x201F,
+        0x204F,
+        0x2E2E,
+        0x2E41,
+        0x2E42,
+        0x2010,
+    ],
     # latin 1 and 2
-    'LGC': char_range(0x20, 0x7e) + char_range(0xa0, 0xff),
-
-    'Lisu': [0x02BC, 0x02CD],  # From Core Specification
-
+    "LGC": char_range(0x20, 0x7E) + char_range(0xA0, 0xFF),
+    "Lisu": [0x02BC, 0x02CD],  # From Core Specification
     # Meriotic Cursive
     # see http://www.unicode.org/L2/L2009/09188r-n3646-meroitic.pdf
     # colon, horizontal ellipsis, tricolon
-    'Merc': [ 0x003A, 0x2026, 0x205D ],
-
+    "Merc": [0x003A, 0x2026, 0x205D],
     # Multani
     # see http://www.unicode.org/L2/L2012/12316-multani.pdf
     # Digits unified with Gurmukhi, but 6 and 7 look like Devanagari, it says.
     # Glyphic variant of section mark 0x112A9, but how would we represent it...
-    'Mult': char_range(0x0A66, 0x0A6F),
-
+    "Mult": char_range(0x0A66, 0x0A6F),
     # Sharada
     # see http://www.unicode.org/L2/L2009/09074-sharada.pdf
     # also see http://www.unicode.org/L2/L2015/15255-sharada-vocalic-vs.pdf
     # which requests a change in the representative glyphs of 111ba and 111bb
     # (below vowel signs)
     # Seems self-contained, no other punctuation.
-    'Shrd': [ ],
-
+    "Shrd": [],
     # Siddham
     # see http://www.unicode.org/L2/L2012/12234r-n4294-siddham.pdf
     # most use in Aast Asia
-    'Sidd': [ ],
-
+    "Sidd": [],
     # Sign Writing
     # As with music notation, we can't lay this out.  Generative glyphs for lots
     # of hand positions...
-    'Sgnw': [ ],
-
-    'Sylo': [0x2055],  # From Core Specification
-
+    "Sgnw": [],
+    "Sylo": [0x2055],  # From Core Specification
     # From Core Specification
-    'Syrc': [
-        0x0303, 0x0304, 0x0307, 0x0308, 0x030A, 0x0320,
-        0x0323, 0x0324, 0x0325, 0x032D, 0x032E, 0x0330,
-        0x060C, 0x061B, 0x061F, 0x0640] + char_range(0x064B, 0x0652),
-
+    "Syrc": [
+        0x0303,
+        0x0304,
+        0x0307,
+        0x0308,
+        0x030A,
+        0x0320,
+        0x0323,
+        0x0324,
+        0x0325,
+        0x032D,
+        0x032E,
+        0x0330,
+        0x060C,
+        0x061B,
+        0x061F,
+        0x0640,
+    ]
+    + char_range(0x064B, 0x0652),
     # From Core Specification & http://www.unicode.org/L2/L2001/01369-n2372.pdf
-    'Tale': [0x0300, 0x0301, 0x0307, 0x0308, 0x030C],
-
+    "Tale": [0x0300, 0x0301, 0x0307, 0x0308, 0x030C],
     # From Core Specificaion and
     # http://www.unicode.org/L2/L2010/10407-ext-tamil-follow2.pdf
-    'Taml': [0x00B2, 0x00B3, 0x2074, 0x2082, 0x2083, 0x2084],
-
+    "Taml": [0x00B2, 0x00B3, 0x2074, 0x2082, 0x2083, 0x2084],
     # From Core Specification and
     # http://www.unicode.org/L2/L2010/10451-patani-proposal.pdf
-    'Thai': [0x02BC, 0x02D7, 0x0303, 0x0331],
-
-    'Zmth': ARABIC_MATH,
-
+    "Thai": [0x02BC, 0x02D7, 0x0303, 0x0331],
+    "Zmth": ARABIC_MATH,
     # Azerbaijani manat, Russian ruble, and Georgian Lari
     # Roozbeh says Coptic Epact doesn't belong in the Arabic fonts, though it's
     # used with Arabic.
-    'Zsym': [0x20BC, 0x20BD, 0x20BE] + COPTIC_EPACT,
+    "Zsym": [0x20BC, 0x20BD, 0x20BE] + COPTIC_EPACT,
 }
 
 EXTRA_CHARACTERS_NEEDED = {
-    'Arab': [
-        0x2010, 0x2011,   # Hyphen and non-breaking hyphen need different shapes
-        0x204F, 0x2E41],  # For Sindhi
-
-    'Avst': [0x2E30, 0x2E31],  # From Core Specification and NamesList.txt
-
+    "Arab": [
+        0x2010,
+        0x2011,  # Hyphen and non-breaking hyphen need different shapes
+        0x204F,
+        0x2E41,
+    ],  # For Sindhi
+    "Avst": [0x2E30, 0x2E31],  # From Core Specification and NamesList.txt
     # From http://www.unicode.org/L2/L2014/14064r-n4537r-cherokee.pdf section 8
-    'Cher': [
-        0x0300, 0x0301, 0x0302, 0x0304, 0x030B,
-        0x030C, 0x0323, 0x0324, 0x0330, 0x0331],
-
+    "Cher": [
+        0x0300,
+        0x0301,
+        0x0302,
+        0x0304,
+        0x030B,
+        0x030C,
+        0x0323,
+        0x0324,
+        0x0330,
+        0x0331,
+    ],
     # From Core Specification
-    'Copt': [
-        0x0300, 0x0304, 0x0305, 0x0307, 0x033F,
-        0x0374, 0x0375, 0xFE24, 0xFE25, 0xFE26],
-
+    "Copt": [
+        0x0300,
+        0x0304,
+        0x0305,
+        0x0307,
+        0x033F,
+        0x0374,
+        0x0375,
+        0xFE24,
+        0xFE25,
+        0xFE26,
+    ],
     # latin 1 and 2
-    'LGC': char_range(0x20, 0x7e) + char_range(0xa0, 0xff),
-
-    'Lisu': [0x02BC, 0x02CD],  # From Core Specification
-
-    'Sylo': [0x2055],  # From Core Specification
-
+    "LGC": char_range(0x20, 0x7E) + char_range(0xA0, 0xFF),
+    "Lisu": [0x02BC, 0x02CD],  # From Core Specification
+    "Sylo": [0x2055],  # From Core Specification
     # From Core Specification
-    'Syrc': [
-        0x0303, 0x0304, 0x0307, 0x0308, 0x030A, 0x0320,
-        0x0323, 0x0324, 0x0325, 0x032D, 0x032E, 0x0330,
-        0x060C, 0x061B, 0x061F, 0x0640] + char_range(0x064B, 0x0652),
-
+    "Syrc": [
+        0x0303,
+        0x0304,
+        0x0307,
+        0x0308,
+        0x030A,
+        0x0320,
+        0x0323,
+        0x0324,
+        0x0325,
+        0x032D,
+        0x032E,
+        0x0330,
+        0x060C,
+        0x061B,
+        0x061F,
+        0x0640,
+    ]
+    + char_range(0x064B, 0x0652),
     # From Core Specification & http://www.unicode.org/L2/L2001/01369-n2372.pdf
-    'Tale': [0x0300, 0x0301, 0x0307, 0x0308, 0x030C],
-
+    "Tale": [0x0300, 0x0301, 0x0307, 0x0308, 0x030C],
     # From Core Specificaion and
     # http://www.unicode.org/L2/L2010/10407-ext-tamil-follow2.pdf
-    'Taml': [0x00B2, 0x00B3, 0x2074, 0x2082, 0x2083, 0x2084],
-
+    "Taml": [0x00B2, 0x00B3, 0x2074, 0x2082, 0x2083, 0x2084],
     # From Core Specification and
     # http://www.unicode.org/L2/L2010/10451-patani-proposal.pdf
-    'Thai': [0x02BC, 0x02D7, 0x0303, 0x0331],
-
+    "Thai": [0x02BC, 0x02D7, 0x0303, 0x0331],
     # Azerbaijani manat, Russian ruble, and Georgian Lari
-    'Zsym': [0x20BC, 0x20BD, 0x20BE],
+    "Zsym": [0x20BC, 0x20BD, 0x20BE],
 }
 
 LGC_CHARACTERS_NOT_NEEDED = frozenset(
-        char_range(0x0370, 0x0373) +
-        [0x0376, 0x0377, 0x03CF, 0x0951, 0x0952, 0x1E9C, 0x1E9D, 0x1E9F] +
-        char_range(0x1EFA, 0x1EFF) +
-        [0x2071] +
-        char_range(0x2095, 0x209C) +
-        char_range(0x2160, 0x2183) +
-        char_range(0x2185, 0x2188) +
-        char_range(0x2C6E, 0x2C70) +
-        char_range(0x2C78, 0x2C7F) +
-        char_range(0x2DE0, 0x2DFF) +
-        char_range(0xA640, 0xA673) +
-        char_range(0xA67C, 0xA697) +
-        char_range(0xA722, 0xA787) +
-        [0xA78D, 0xA78E, 0xA790, 0xA791] +
-        char_range(0xA7A0, 0xA7A9) +
-        char_range(0xA7FA, 0xA7FF) +
-        [0xA92E, 0xFB00, 0xFB05, 0xFB06])
+    char_range(0x0370, 0x0373)
+    + [0x0376, 0x0377, 0x03CF, 0x0951, 0x0952, 0x1E9C, 0x1E9D, 0x1E9F]
+    + char_range(0x1EFA, 0x1EFF)
+    + [0x2071]
+    + char_range(0x2095, 0x209C)
+    + char_range(0x2160, 0x2183)
+    + char_range(0x2185, 0x2188)
+    + char_range(0x2C6E, 0x2C70)
+    + char_range(0x2C78, 0x2C7F)
+    + char_range(0x2DE0, 0x2DFF)
+    + char_range(0xA640, 0xA673)
+    + char_range(0xA67C, 0xA697)
+    + char_range(0xA722, 0xA787)
+    + [0xA78D, 0xA78E, 0xA790, 0xA791]
+    + char_range(0xA7A0, 0xA7A9)
+    + char_range(0xA7FA, 0xA7FF)
+    + [0xA92E, 0xFB00, 0xFB05, 0xFB06]
+)
 
 P3_CHARACTERS_NOT_NEEDED = {
-    'Arab': char_range(0x10E60, 0x10E7E) + COPTIC_EPACT + ARABIC_MATH,
-    'Latn': LGC_CHARACTERS_NOT_NEEDED,
-    'LGC': LGC_CHARACTERS_NOT_NEEDED,
+    "Arab": char_range(0x10E60, 0x10E7E) + COPTIC_EPACT + ARABIC_MATH,
+    "Latn": LGC_CHARACTERS_NOT_NEEDED,
+    "LGC": LGC_CHARACTERS_NOT_NEEDED,
 }
 
 CHARACTERS_NOT_NEEDED = {
-    'Arab': char_range(0x10E60, 0x10E7E),
-    'Latn': LGC_CHARACTERS_NOT_NEEDED,
-    'LGC': LGC_CHARACTERS_NOT_NEEDED,
+    "Arab": char_range(0x10E60, 0x10E7E),
+    "Latn": LGC_CHARACTERS_NOT_NEEDED,
+    "LGC": LGC_CHARACTERS_NOT_NEEDED,
 }
 
 ACCEPTABLE_AS_COMBINING = {
@@ -487,22 +633,22 @@ ACCEPTABLE_AS_COMBINING = {
 
 
 def get_extra_characters_needed(script, phase):
-  try:
-    if phase == 2:
-      return set(EXTRA_CHARACTERS_NEEDED[script])
-    if phase == 3:
-      return set(P3_EXTRA_CHARACTERS_NEEDED[script])
-  except KeyError:
-    pass
-  return set()
+    try:
+        if phase == 2:
+            return set(EXTRA_CHARACTERS_NEEDED[script])
+        if phase == 3:
+            return set(P3_EXTRA_CHARACTERS_NEEDED[script])
+    except KeyError:
+        pass
+    return set()
 
 
 def get_characters_not_needed(script, phase):
-  try:
-    if phase == 2:
-      return set(CHARACTERS_NOT_NEEDED[script])
-    if phase == 3:
-      return set(P3_CHARACTERS_NOT_NEEDED[script])
-  except KeyError:
-    pass
-  return set()
+    try:
+        if phase == 2:
+            return set(CHARACTERS_NOT_NEEDED[script])
+        if phase == 3:
+            return set(P3_CHARACTERS_NOT_NEEDED[script])
+    except KeyError:
+        pass
+    return set()
